@@ -17,6 +17,8 @@ class Operators(Enum):
     NOT_IN = "notin"
     HAS = "has"
     ANY = "any"
+    BETWEEN = "<>"
+    BETWEEN_OR_EQUAL = "<==>"
 
     def equals(self, val):
         if type(val) == str:
