@@ -115,9 +115,11 @@ def get_conditions_from_dict(values: dict, model=None, optional: bool = False):
                 elif Operators.INFERIOR_OR_EQUAL.equals(k):
                     conditions.append(key <= v)
                 elif Operators.NOT_IN.equals(k):
-                    conditions.append(key.notin_(v if isinstance(v, Iterable) else [v]))
+                    v = v if isinstance(v, Iterable) else [v]
+                    conditions.append(key.notin_([v.value for v in v] if all([issubclass(type(v), enum.Enum) for v in v]) else v))
                 elif Operators.IN.equals(k):
-                    conditions.append(key.in_(v if isinstance(v, Iterable) else [v]))
+                    v = v if isinstance(v, Iterable) else [v]
+                    conditions.append(key.in_([v.value for v in v] if all([issubclass(type(v), enum.Enum) for v in v]) else v))
                 elif Operators.HAS.equals(k):
                     v = get_filters(v, None, optional=optional)
                     for condition in v:
@@ -232,7 +234,7 @@ def apply_order_by(query, order_by, order_by_direction, model):
         return query
 
     if type(order_by) != tuple and type(order_by) != list:
-        query = query.order_by(order_by)
+        query = query.order_by(convert_order_by_str(model, order_by, order_by_direction))
     else:
         if order_by_direction is not None and len(order_by) == len(order_by_direction):
             order_by_list = [
@@ -392,9 +394,13 @@ class AlphaDatabase(AlphaDatabaseCore):
     def truncate(self, table_model, bind=None):
         self.execute(f"truncate table {table_model.__tablename__}", bind=bind)
         if self.db_type == "oracle":
-            self.execute(
-                f"ALTER TABLE {table_model.__tablename__} MODIFY(ID Generated as Identity (START WITH 1));"
-            )
+            try:
+                self.execute(
+                    f"ALTER TABLE {table_model.__tablename__} MODIFY(ID Generated as Identity (START WITH 1));"
+                )
+            except:
+                # TODO: modify
+                pass
 
     def execute(self, query, values=None, commit=True, bind: str = None, close=False):
         return self.execute_query(query, values, commit=commit, bind=bind, close=close)
